@@ -899,7 +899,7 @@ class UnifiClient(AbstractUnifiSession):
         '''
             List all params from dashboad/clients, include all activeclients, client ap conected, active down/up per client, ip, name, wlan, channel and others stats.
             Case macs is None, this request bring data from all AP's. Case especific mac in this request, this request bring data from this AP's.
-
+            -
             Required: site[site code string]
             Optional: macs[array of macs]
             Example:
@@ -962,3 +962,11 @@ class UnifiClient(AbstractUnifiSession):
         '''
         r = self.post(self.endpoint('/api/s/{}/stat/widget/health' .format(site)))
         return self.process_response(r)
+
+    @requires_login
+    def stat_clients(self, site):
+        '''
+            List all users connected, pending and others stats.
+        '''
+        r = self.get(self.endpoint('/api/s/{}/stat/sta' .formart(site))
+        return self.process_response(r)
